@@ -30,11 +30,7 @@ pub struct AdminCancelTask<'info> {
 }
 
 pub fn handler(ctx: Context<AdminCancelTask>) -> ProgramResult {
-    // Get accounts.
     let task = &mut ctx.accounts.task;
-
-    // Mark task as cancelled.
-    task.status = TaskStatus::Cancelled;
-
-    Ok(())
+    
+    task.cancel()
 }
