@@ -42,20 +42,10 @@ pub struct DaemonCreate<'info> {
 }
 
 pub fn handler(ctx: Context<DaemonCreate>, daemon_bump: u8, fee_bump: u8) -> ProgramResult {
-    // Get accounts.
     let daemon = &mut ctx.accounts.daemon;
     let fee = &mut ctx.accounts.fee;
     let owner = &ctx.accounts.owner;
 
-    // Initialize daemon account.
-    daemon.owner = owner.key();
-    daemon.task_count = 0;
-    daemon.bump = daemon_bump;
-
-    // Initialize fee account.
-    fee.daemon = daemon.key();
-    fee.balance = 0;
-    fee.bump = fee_bump;
-
-    Ok(())
+    daemon.init(owner.key(), daemon_bump)?;
+    fee.init(daemon.key(), fee_bump)
 }
